@@ -27,7 +27,7 @@ QTEST_MAIN(ComposerTest)
 
 void ComposerTest::testAttachments()
 {
-    Composer *composer = new Composer;
+    auto *composer = new Composer;
     fillComposerData(composer);
     AttachmentPart::Ptr attachment = AttachmentPart::Ptr(new AttachmentPart);
     attachment->setData("abc");
@@ -43,26 +43,26 @@ void ComposerTest::testAttachments()
     // multipart/mixed
     {
         QVERIFY(message->contentType(false));
-        QCOMPARE(message->contentType()->mimeType(), QByteArray("multipart/mixed"));
+        QCOMPARE(message->contentType(false)->mimeType(), QByteArray("multipart/mixed"));
         QCOMPARE(message->contents().count(), 2);
         // text/plain
         {
             Content *plain = message->contents().at(0);
             QVERIFY(plain->contentType(false));
-            QCOMPARE(plain->contentType()->mimeType(), QByteArray("text/plain"));
+            QCOMPARE(plain->contentType(false)->mimeType(), QByteArray("text/plain"));
         }
         // x-some/x-type (attachment)
         {
             Content *plain = message->contents().at(1);
             QVERIFY(plain->contentType(false));
-            QCOMPARE(plain->contentType()->mimeType(), QByteArray("x-some/x-type"));
+            QCOMPARE(plain->contentType(false)->mimeType(), QByteArray("x-some/x-type"));
         }
     }
 }
 
 void ComposerTest::testAutoSave()
 {
-    Composer *composer = new Composer;
+    auto *composer = new Composer;
     fillComposerData(composer);
     AttachmentPart::Ptr attachment = AttachmentPart::Ptr(new AttachmentPart);
     attachment->setData("abc");
@@ -124,7 +124,7 @@ void ComposerTest::testBug271192()
 {
     const QString displayName = QStringLiteral("Интернет-компания example");
     const QString mailbox = QStringLiteral("example@example.com");
-    Composer *composer = new Composer;
+    auto *composer = new Composer;
     fillComposerData(composer);
     composer->infoPart()->setTo(QStringList() << (displayName + QLatin1String(" <") + mailbox + QLatin1String(">")));
     QVERIFY(composer->exec());
