@@ -72,7 +72,7 @@ void CryptoComposerTest::testOpenPGPMime()
     QFETCH(bool, encrypt);
     QFETCH(Headers::contentEncoding, cte);
 
-    Composer *composer = new Composer;
+    auto *composer = new Composer;
 
     fillComposerData(composer, data);
     fillComposerCryptoData(composer);
@@ -108,7 +108,7 @@ void CryptoComposerTest::testEncryptSameAttachments_data()
 void CryptoComposerTest::testEncryptSameAttachments()
 {
     QFETCH(int, format);
-    Composer *composer = new Composer;
+    auto *composer = new Composer;
     QString data(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     fillComposerData(composer, data);
     fillComposerCryptoData(composer);
@@ -140,7 +140,7 @@ void CryptoComposerTest::testEncryptSameAttachments()
 
     MimeTreeParser::SimpleObjectTreeSource testSource;
     testSource.setDecryptMessage(true);
-    MimeTreeParser::NodeHelper *nh = new MimeTreeParser::NodeHelper;
+    auto *nh = new MimeTreeParser::NodeHelper;
     MimeTreeParser::ObjectTreeParser otp(&testSource, nh);
 
     otp.parseObjectTree(message.data());
@@ -162,7 +162,7 @@ void CryptoComposerTest::testEditEncryptAttachments_data()
 void CryptoComposerTest::testEditEncryptAttachments()
 {
     QFETCH(int, format);
-    Composer *composer = new Composer;
+    auto *composer = new Composer;
     QString data(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     fillComposerData(composer, data);
     fillComposerCryptoData(composer);
@@ -218,7 +218,7 @@ void CryptoComposerTest::testEditEncryptAndLateAttachments_data()
 void CryptoComposerTest::testEditEncryptAndLateAttachments()
 {
     QFETCH(int, format);
-    Composer *composer = new Composer;
+    auto *composer = new Composer;
     QString data(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     fillComposerData(composer, data);
     fillComposerCryptoData(composer);
@@ -287,7 +287,7 @@ void CryptoComposerTest::testSignEncryptLateAttachments_data()
 void CryptoComposerTest::testSignEncryptLateAttachments()
 {
     QFETCH(int, format);
-    Composer *composer = new Composer;
+    auto *composer = new Composer;
     QString data(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     fillComposerData(composer, data);
     fillComposerCryptoData(composer);
@@ -322,6 +322,77 @@ void CryptoComposerTest::testSignEncryptLateAttachments()
     QCOMPARE(QString::fromLatin1(MessageCore::NodeHelper::nextSibling(b)->body()), QString::fromLatin1("abc"));
 }
 
+// protected headers
+void CryptoComposerTest::testProtectedHeaders_data()
+{
+    QTest::addColumn<QString>("data");
+    QTest::addColumn<bool>("sign");
+    QTest::addColumn<bool>("encrypt");
+    QTest::addColumn<Headers::contentEncoding>("cte");
+
+    QString data(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
+    QTest::newRow("SignOpenPGPMime") << data << true << false << Headers::CE7Bit;
+    QTest::newRow("EncryptOpenPGPMime") << data << false << true << Headers::CE7Bit;
+    QTest::newRow("SignEncryptOpenPGPMime") << data << true << true << Headers::CE7Bit;
+}
+
+void CryptoComposerTest::testProtectedHeaders()
+{
+    QFETCH(QString, data);
+    QFETCH(bool, sign);
+    QFETCH(bool, encrypt);
+    QFETCH(Headers::contentEncoding, cte);
+
+    Composer composer;
+
+    fillComposerData(&composer, data);
+    fillComposerCryptoData(&composer);
+
+    composer.setSignAndEncrypt(sign, encrypt);
+    composer.setMessageCryptoFormat(Kleo::OpenPGPMIMEFormat);
+
+    VERIFYEXEC((&composer));
+    QCOMPARE(composer.resultMessages().size(), 1);
+
+    KMime::Message::Ptr message = composer.resultMessages().first();
+
+    // parse the result and make sure it is valid in various ways
+    MimeTreeParser::SimpleObjectTreeSource testSource;
+    MimeTreeParser::NodeHelper nh;
+    MimeTreeParser::ObjectTreeParser otp(&testSource, &nh);
+
+    testSource.setDecryptMessage(true);
+    otp.parseObjectTree(message.data());
+
+    if (encrypt) {
+        QCOMPARE(nh.encryptionState(message.data()), MimeTreeParser::KMMsgFullyEncrypted);
+    }
+
+    if (sign && !encrypt) {
+        QCOMPARE(nh.signatureState(message.data()), MimeTreeParser::KMMsgFullySigned);
+    }
+
+    KMime::Content *part = nullptr;
+
+    if (sign && !encrypt) {
+        part = Util::findTypeInMessage(message.data(), "text", "plain");
+    } else if (encrypt) {
+        auto extraContents = nh.extraContents(message.data());
+        QCOMPARE(extraContents.size(), 1);
+        part =  extraContents.first();
+        if (sign) {
+            QVERIFY(!part->contentType(false)->hasParameter(QStringLiteral("protected-headers")));
+            QVERIFY(!part->headerByType("to"));
+            QVERIFY(!part->headerByType("from:"));
+            part = Util::findTypeInMessage(part, "text", "plain");
+        }
+    }
+    QVERIFY(part);
+    QCOMPARE(part->contentType(false)->parameter(QStringLiteral("protected-headers")),QStringLiteral("v1"));
+    QCOMPARE(part->headerByType("to")->asUnicodeString(), QStringLiteral("you@you.you"));
+    QCOMPARE(part->headerByType("from")->asUnicodeString(), QStringLiteral("me@me.me"));
+}
+
 void CryptoComposerTest::testBCCEncrypt_data()
 {
     QTest::addColumn<int>("format");
@@ -335,7 +406,7 @@ void CryptoComposerTest::testBCCEncrypt_data()
 void CryptoComposerTest::testBCCEncrypt()
 {
     QFETCH(int, format);
-    Composer *composer = new Composer;
+    auto *composer = new Composer;
     QString data(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     fillComposerData(composer, data);
     composer->infoPart()->setBcc(QStringList(QStringLiteral("bcc@bcc.org")));
@@ -404,7 +475,7 @@ void CryptoComposerTest::testOpenPGPInline()
     QFETCH(bool, encrypt);
     QFETCH(Headers::contentEncoding, cte);
 
-    Composer *composer = new Composer;
+    auto *composer = new Composer;
 
     fillComposerData(composer, data);
     fillComposerCryptoData(composer);
@@ -555,7 +626,7 @@ void CryptoComposerTest::runSMIMETest(bool sign, bool enc, bool opaque)
     QFETCH(QString, data);
     QFETCH(Headers::contentEncoding, cte);
 
-    Composer *composer = new Composer;
+    auto *composer = new Composer;
 
     fillComposerData(composer, data);
     composer->infoPart()->setFrom(QStringLiteral("test@example.com"));
