@@ -1,20 +1,8 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
@@ -188,6 +176,8 @@ QString Theme::ContentItem::description(Type type)
         return i18n("Note Icon");
     case InvitationIcon:
         return i18n("Invitation Icon");
+    case Folder:
+        return i18nc("Description of Type Folder", "Folder");
     default:
         return i18nc("Description for an Unknown Type", "Unknown");
         break;
@@ -336,6 +326,7 @@ bool Theme::ContentItem::load(QDataStream &stream, int /*themeVersion*/)
     case TagList:
     case AnnotationIcon:
     case InvitationIcon:
+    case Folder:
         // ok
         break;
     default:
@@ -477,7 +468,7 @@ bool Theme::Row::LoadContentItem(int val, QDataStream &stream, int themeVersion,
     // FIXME: Remove code duplication here
 
     for (int i = 0; i < val; ++i) {
-        ContentItem *ci = new ContentItem(ContentItem::Subject);    // dummy type
+        auto *ci = new ContentItem(ContentItem::Subject);    // dummy type
         if (!ci->load(stream, themeVersion)) {
             qCDebug(MESSAGELIST_LOG) << "Left content item loading failed";
             delete ci;
@@ -496,7 +487,7 @@ bool Theme::Row::LoadContentItem(int val, QDataStream &stream, int themeVersion,
             && themeVersion < gThemeMinimumVersionWithAnnotationIcon
             && val > 1) {
             qCDebug(MESSAGELIST_LOG) << "Old theme version detected, adding annotation item next to attachment icon.";
-            ContentItem *annotationItem = new ContentItem(ContentItem::AnnotationIcon);
+            auto *annotationItem = new ContentItem(ContentItem::AnnotationIcon);
             annotationItem->setHideWhenDisabled(true);
             if (leftItem) {
                 addLeftItem(annotationItem);
@@ -510,7 +501,7 @@ bool Theme::Row::LoadContentItem(int val, QDataStream &stream, int themeVersion,
             && themeVersion < gThemeMinimumVersionWithInvitationIcon
             && val > 1) {
             qCDebug(MESSAGELIST_LOG) << "Old theme version detected, adding invitation item next to attachment icon.";
-            ContentItem *invitationItem = new ContentItem(ContentItem::InvitationIcon);
+            auto *invitationItem = new ContentItem(ContentItem::InvitationIcon);
             invitationItem->setHideWhenDisabled(true);
             if (leftItem) {
                 addLeftItem(invitationItem);
@@ -1062,7 +1053,7 @@ void Theme::setGroupHeaderBackgroundStyle(Theme::GroupHeaderBackgroundStyle grou
     mGroupHeaderBackgroundStyle = groupHeaderBackgroundStyle;
 }
 
-QList<QPair<QString, int> > Theme::enumerateViewHeaderPolicyOptions()
+QVector<QPair<QString, int> > Theme::enumerateViewHeaderPolicyOptions()
 {
     return { {
         i18n("Never Show"), NeverShowHeader
@@ -1072,7 +1063,7 @@ QList<QPair<QString, int> > Theme::enumerateViewHeaderPolicyOptions()
         } };
 }
 
-QList<QPair<QString, int> > Theme::enumerateGroupHeaderBackgroundStyles()
+QVector<QPair<QString, int> > Theme::enumerateGroupHeaderBackgroundStyles()
 {
     return { {
         i18n("Plain Rectangles"), PlainRect
@@ -1209,7 +1200,7 @@ bool Theme::load(QDataStream &stream)
     }
 
     for (int i = 0; i < val; ++i) {
-        Column *col = new Column();
+        auto *col = new Column();
         if (!col->load(stream, themeVersion)) {
             qCDebug(MESSAGELIST_LOG) << "Column loading failed";
             delete col;
@@ -1263,9 +1254,9 @@ void Theme::populatePixmapCache() const
              << new QPixmap(QIcon::fromTheme(QStringLiteral("mail-mark-task")).pixmap(mIconSize, mIconSize))
              << new QPixmap(QIcon::fromTheme(QStringLiteral("mail-sent")).pixmap(mIconSize, mIconSize))
              << new QPixmap(QIcon::fromTheme(QStringLiteral("mail-forwarded")).pixmap(mIconSize, mIconSize))
-             << new QPixmap(QIcon::fromTheme(QStringLiteral("emblem-important")).pixmap(mIconSize, mIconSize))  // "flag"
-             << new QPixmap(QIcon::fromTheme(QStringLiteral("messagelist/pics/mail-thread-watch.png")).pixmap(mIconSize, mIconSize))
-             << new QPixmap(QIcon::fromTheme(QStringLiteral("messagelist/pics/mail-thread-ignored.png")).pixmap(mIconSize, mIconSize))
+             << new QPixmap(QIcon::fromTheme(QStringLiteral("mail-mark-important")).pixmap(mIconSize, mIconSize))  // "flag"
+             << new QPixmap(QIcon::fromTheme(QStringLiteral("mail-thread-watch")).pixmap(mIconSize, mIconSize))
+             << new QPixmap(QIcon::fromTheme(QStringLiteral("mail-thread-ignored")).pixmap(mIconSize, mIconSize))
              << new QPixmap(QIcon::fromTheme(QStringLiteral("mail-mark-junk")).pixmap(mIconSize, mIconSize))
              << new QPixmap(QIcon::fromTheme(QStringLiteral("mail-mark-notjunk")).pixmap(mIconSize, mIconSize))
              << new QPixmap(QIcon::fromTheme(QStringLiteral("mail-signed-verified")).pixmap(mIconSize, mIconSize))
