@@ -700,7 +700,8 @@ void DefaultRendererPrivate::render(const AlternativeMessagePart::Ptr &mp, HtmlW
 
     auto mode = mp->preferredMode();
     if (mode == MimeTreeParser::Util::MultipartPlain && mp->text().trimmed().isEmpty()) {
-        for (const auto m : mp->availableModes()) {
+        const auto availableModes = mp->availableModes();
+        for (const auto m : availableModes) {
             if (m != MimeTreeParser::Util::MultipartPlain) {
                 mode = m;
                 break;
@@ -735,7 +736,7 @@ void DefaultRendererPrivate::render(const CertMessagePart::Ptr &mp, HtmlWriter *
 
     auto end(imports.end());
     for (auto it = imports.begin(); it != end; ++it) {
-        QObject *key(new QObject(mp.data()));
+        auto *key(new QObject(mp.data()));
         key->setProperty("error", QString::fromLocal8Bit((*it).error().asString()));
         key->setProperty("status", (*it).status());
         key->setProperty("fingerprint", QLatin1String((*it).fingerprint()));
