@@ -25,9 +25,6 @@ public:
 
     virtual void showConfigureDialog(QWidget *parent);
 
-    Q_REQUIRED_RESULT bool isEnabled() const;
-    void setIsEnabled(bool enabled);
-
 Q_SIGNALS:
     void configChanged();
 
