@@ -1,28 +1,19 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
    Code based in v4_rice.cc
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "riceencodingdecoder.h"
 #include "webengineviewer_debug.h"
 
+#ifdef WIN32
+#include <Winsock2.h>
+#else
 #include <netinet/in.h>
+#endif
 
 namespace {
 const int kBitsPerByte = 8;
@@ -38,17 +29,17 @@ RiceEncodingDecoder::~RiceEncodingDecoder()
 {
 }
 
-QList<quint32> RiceEncodingDecoder::decodeRiceIndiceDelta(const RiceDeltaEncoding &riceDeltaEncoding)
+QVector<quint32> RiceEncodingDecoder::decodeRiceIndiceDelta(const RiceDeltaEncoding &riceDeltaEncoding)
 {
     bool ok;
-    QList<quint32> list;
+    QVector<quint32> list;
     if (riceDeltaEncoding.firstValue.isEmpty()) {
         return list;
     }
     quint64 firstValue = riceDeltaEncoding.firstValue.toInt(&ok);
     if (!ok) {
         qCWarning(WEBENGINEVIEWER_LOG) << "First value is not a int value " << riceDeltaEncoding.firstValue;
-        return QList<quint32>();
+        return QVector<quint32>();
     }
     list.reserve(riceDeltaEncoding.numberEntries + 1);
     list << firstValue;
@@ -62,7 +53,7 @@ QList<quint32> RiceEncodingDecoder::decodeRiceIndiceDelta(const RiceDeltaEncodin
         quint32 offset;
         bool result = decoder.nextValue(&offset);
         if (!result) {
-            return QList<quint32>();
+            return QVector<quint32>();
         }
         lastValue += offset;
 #if 0
@@ -77,9 +68,9 @@ QList<quint32> RiceEncodingDecoder::decodeRiceIndiceDelta(const RiceDeltaEncodin
     return list;
 }
 
-QList<quint32> RiceEncodingDecoder::decodeRiceHashesDelta(const RiceDeltaEncoding &riceDeltaEncoding)
+QVector<quint32> RiceEncodingDecoder::decodeRiceHashesDelta(const RiceDeltaEncoding &riceDeltaEncoding)
 {
-    QList<quint32> list;
+    QVector<quint32> list;
     bool ok = false;
     quint64 firstValue = riceDeltaEncoding.firstValue.toInt(&ok);
     if (!ok) {
@@ -96,7 +87,7 @@ QList<quint32> RiceEncodingDecoder::decodeRiceHashesDelta(const RiceDeltaEncodin
         quint32 offset;
         bool result = decoder.nextValue(&offset);
         if (!result) {
-            return QList<quint32>();
+            return QVector<quint32>();
         }
 
         lastValue += offset;
@@ -116,7 +107,7 @@ QList<quint32> RiceEncodingDecoder::decodeRiceHashesDelta(const RiceDeltaEncodin
 
     // This flipping is done so that when the vector is interpreted as a string,
     // the bytes are in the correct order.
-    QList<quint32> newList;
+    QVector<quint32> newList;
     newList.reserve(list.count());
     const int listCount(list.count());
     for (int i = 0; i < listCount; ++i) {
