@@ -1,26 +1,12 @@
 /*
-   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "testwebengine.h"
 #include <QHBoxLayout>
 #include <QApplication>
-#include <QWebEngineView>
 #include <WebEngineViewer/WebHitTestResult>
 #include <WebEngineViewer/WebEnginePage>
 #include <QDebug>
@@ -31,8 +17,8 @@
 TestWebEngine::TestWebEngine(QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *hboxLayout = new QHBoxLayout(this);
-    TestWebEngineView *pageView = new TestWebEngineView(this);
+    auto *hboxLayout = new QHBoxLayout(this);
+    auto *pageView = new TestWebEngineView(this);
     hboxLayout->addWidget(pageView);
     mEnginePage = new WebEngineViewer::WebEnginePage(this);
     pageView->setPage(mEnginePage);
@@ -76,8 +62,9 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    TestWebEngine *testWebEngine = new TestWebEngine;
+    auto *testWebEngine = new TestWebEngine;
     testWebEngine->show();
+    testWebEngine->resize(600, 400);
     const int ret = app.exec();
     return ret;
 }
